@@ -35,22 +35,17 @@ namespace VCalDrag {
 /**
   Mime-type of iCalendar
 */
-KCALUTILS_EXPORT QString mimeType();
-
-/**
-  Sets the vCalendar representation as data of the drag object
-*/
-KCALUTILS_EXPORT bool populateMimeData(QMimeData *e, const KCalCore::MemoryCalendar::Ptr &cal);
+Q_REQUIRED_RESULT KCALUTILS_EXPORT QString mimeType();
 
 /**
   Return, if drag&drop object can be decode to vCalendar.
 */
-KCALUTILS_EXPORT bool canDecode(const QMimeData *);
+Q_REQUIRED_RESULT KCALUTILS_EXPORT bool canDecode(const QMimeData *);
 
 /**
   Decode drag&drop object to vCalendar component \a vcal.
 */
-KCALUTILS_EXPORT bool fromMimeData(const QMimeData *e, const KCalCore::MemoryCalendar::Ptr &cal);
+Q_REQUIRED_RESULT KCALUTILS_EXPORT bool fromMimeData(const QMimeData *e, const KCalCore::MemoryCalendar::Ptr &cal);
 }
 }
 
